==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebColumnSelectionEventArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { WebBaseEventArgsDetailDescription } from "./WebBaseEventArgsDetailDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebColumnSelectionEventArgsDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnSelectionEventArgsDetailDescription, _super);
    function WebColumnSelectionEventArgsDetailDescription() {
        var _this = _super.call(this) || this;
        _this.o = null;
        _this.n = null;
        _this.m = null;
        _this.p = null;
        return _this;
    }
    WebColumnSelectionEventArgsDetailDescription.prototype.get_type = function () {
        return "WebColumnSelectionEventArgsDetail";
    };
    Object.defineProperty(WebColumnSelectionEventArgsDetailDescription.prototype, "oldSelection", {
        get: function () {
            return this.o;
        },
        set: function (a) {
            this.o = a;
            this.g("OldSelection");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebColumnSelectionEventArgsDetailDescription.prototype, "newSelection", {
        get: function () {
            return this.n;
        },
        set: function (a) {
            this.n = a;
            this.g("NewSelection");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebColumnSelectionEventArgsDetailDescription.prototype, "added", {
        get: function () {
            return this.m;
        },
        set: function (a) {
            this.m = a;
            this.g("Added");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebColumnSelectionEventArgsDetailDescription.prototype, "removed", {
        get: function () {
            return this.p;
        },
        set: function (a) {
            this.p = a;
            this.g("Removed");
        },
        enumerable: false,
        configurable: true
    });
    WebColumnSelectionEventArgsDetailDescription.$t = markType(WebColumnSelectionEventArgsDetailDescription, 'WebColumnSelectionEventArgsDetailDescription', WebBaseEventArgsDetailDescription.$);
    WebColumnSelectionEventArgsDetailDescription.__marshalByValue1 = true;
    WebColumnSelectionEventArgsDetailDescription.__marshalByValueAlias1 = "ColumnSelectionEventArgsDetail";
    return WebColumnSelectionEventArgsDetailDescription;
}(WebBaseEventArgsDetailDescription));
export { WebColumnSelectionEventArgsDetailDescription };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebColumnSelectionEventArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebColumnSelectionEventArgsDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnSelectionEventArgsDetailDescription, _super);
    function WebColumnSelectionEventArgsDetailDescription() {
        var _this = _super.call(this) || this;
        _this.j = null;
        _this.i = null;
        _this.h = null;
        _this.k = null;
        _this.q = false;
        _this.s = null;
        return _this;
    }
    WebColumnSelectionEventArgsDetailDescription.prototype.get_type = function () {
        return "WebColumnSelectionEventArgsDetail";
    };
    Object.defineProperty(WebColumnSelectionEventArgsDetailDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebColumnSelectionEventArgsDetailDescription.prototype, "oldSelection", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.g("OldSelection");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebColumnSelectionEventArgsDetailDescription.prototype, "newSelection", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.g("NewSelection");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebColumnSelectionEventArgsDetailDescription.prototype, "added", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("Added");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebColumnSelectionEventArgsDetailDescription.prototype, "removed", {
        get: function () {
            return this.k;
        },
        set: function (a) {
            this.k = a;
            this.g("Removed");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebColumnSelectionEventArgsDetailDescription.prototype, "cancel", {
        get: function () {
            return this.q;
        },
        set: function (a) {
            this.q = a;
            this.g("Cancel");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebColumnSelectionEventArgsDetailDescription.prototype, "owner", {
        get: function () {
            return this.s;
        },
        set: function (a) {
            this.s = a;
            this.g("Owner");
        },
        enumerable: false,
        configurable: true
    });
    WebColumnSelectionEventArgsDetailDescription.$t = markType(WebColumnSelectionEventArgsDetailDescription, 'WebColumnSelectionEventArgsDetailDescription', Description.$);
    WebColumnSelectionEventArgsDetailDescription.__marshalByValue = true;
    WebColumnSelectionEventArgsDetailDescription.__marshalByValueAlias = "ColumnSelectionEventArgsDetail";
    return WebColumnSelectionEventArgsDetailDescription;
}(Description));
export { WebColumnSelectionEventArgsDetailDescription };
